@@ -53,7 +53,7 @@ recover_conference.prcomp <- function(x) {
 recover_aug_rows.prcomp <- function(x) {
   name <- rownames(x[["x"]])
   if (is.null(name)) {
-    tibble_pole(nrow(x[["x"]]))
+    tibble(.rows = nrow(x[["x"]]))
   } else {
     tibble(name = name)
   }
@@ -64,7 +64,7 @@ recover_aug_rows.prcomp <- function(x) {
 recover_aug_cols.prcomp <- function(x) {
   name <- rownames(x[["rotation"]])
   res <- if (is.null(name)) {
-    tibble_pole(nrow(x[["rotation"]]))
+    tibble(.rows = nrow(x[["rotation"]]))
   } else {
     tibble(name = name)
   }
