@@ -2,13 +2,21 @@
 #'
 #' @description These methods extract data from, and attribute new data to,
 #'   objects of class `"princomp"` as returned by [stats::princomp()].
+#'   
+#' @details
+#' 
+#' Principal components analysis (PCA), as performed by [stats::princomp()],
+#' relies on an eigenvalue decomposition (EVD) of the covariance matrix 
+#' \eqn{X^TX} of a data set \eqn{X}. [stats::princomp()] returns the EVD factor
+#' \eqn{V} as the loadings `$loadings`. The scores `$scores` are obtained as
+#' \eqn{XV} and are accessible as supplementary elements.
 #'
 #' @name methods-princomp
-#' @author Emily Paul
+#' @author Emily Paul, John Gracey
 #' @include ord-tbl.r
 #' @template param-methods
 #' @template return-methods
-#' @family methods for singular value decomposition-based techniques
+#' @family methods for eigen-decomposition-based techniques
 #' @family models from the stats package
 #' @example inst/examples/ex-methods-princomp-iris.r
 NULL
@@ -20,7 +28,10 @@ as_tbl_ord.princomp <- as_tbl_ord_default
 #' @rdname methods-princomp
 #' @export
 recover_rows.princomp <- function(x) {
-  x[["scores"]]
+  matrix(
+    nrow = 0, ncol = ncol(x[["scores"]]),
+    dimnames = list(NULL, colnames(x[["scores"]]))
+  )
 }
 
 #' @rdname methods-princomp
@@ -48,15 +59,29 @@ recover_conference.princomp <- function(x) {
   c(1, 0)
 }
 
+#' @rdname methods-princomp
+#' @export
+recover_supp_rows.princomp <- function(x) {
+  x[["scores"]]
+}
+
 #' @rdname methods-princomp
 #' @export
 recover_aug_rows.princomp <- function(x) {
-  name <- rownames(x[["scores"]])
-  if (is.null(name)) {
-    tibble_pole(nrow(x[["scores"]]))
+  res <- tibble(.rows = 0L)
+  
+  # scores as supplementary points
+  name <- rownames(x$scores)
+  res_sup <- if (is.null(name)) {
+    tibble(.rows = nrow(x$scores))
   } else {
     tibble(name = name)
   }
+  
+  # supplement flag
+  res$.element <- "active"
+  res_sup$.element <- "score"
+  as_tibble(dplyr::bind_rows(res, res_sup))
 }
 
 #' @rdname methods-princomp
@@ -64,14 +89,16 @@ recover_aug_rows.princomp <- function(x) {
 recover_aug_cols.princomp <- function(x) {
   name <- rownames(x[["loadings"]])
   res <- if (is.null(name)) {
-    tibble_pole(nrow(x[["loadings"]]))
+    tibble(.rows = nrow(x[["loadings"]]))
   } else {
     tibble(name = name)
   }
-  bind_cols(res, tibble(
+  res <- bind_cols(res, tibble(
     center = x[["center"]],
     scale = x[["scale"]]
   ))
+  res$.element <- "active"
+  res
 }
 
 #' @rdname methods-princomp
